aboutsummaryrefslogtreecommitdiff
path: root/src/settings.js
diff options
context:
space:
mode:
authorDan Gohman <sunfish@google.com>2014-02-20 17:24:22 -0800
committerDan Gohman <sunfish@google.com>2014-02-25 11:58:52 -0800
commit264a5a91c450b510bcee1d257372ee5d9750879b (patch)
tree4f6f79a60d1b20d5f81bdae873b548cc55644a59 /src/settings.js
parente6f7d1edbe66e4ee676413de57a96222add7a3fd (diff)
Introduce the asmjs-unknown-emscripten target triple.
Diffstat (limited to 'src/settings.js')
-rw-r--r--src/settings.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/settings.js b/src/settings.js
index 1c6b998e..7f9fbabf 100644
--- a/src/settings.js
+++ b/src/settings.js
@@ -23,8 +23,8 @@ var QUANTUM_SIZE = 4; // This is the size of an individual field in a structure.
// Changing this from the default of 4 is deprecated.
var TARGET_X86 = 0; // For i386-pc-linux-gnu
-var TARGET_LE32 = 1; // For le32-unknown-nacl. 1 is normal, 2 is for the fastcomp llvm
- // backend using pnacl abi simplification
+var TARGET_ASMJS_UNKNOWN_EMSCRIPTEN = 1; // For asmjs-unknown-emscripten. 1 is normal, 2 is for the fastcomp llvm
+ // backend using emscripten-customized abi simplification
var CORRECT_SIGNS = 1; // Whether we make sure to convert unsigned values to signed values.
// Decreases performance with additional runtime checks. Might not be